@@ -43,7 +43,6 @@ var pageName;
 var columnsHidden = 0;
 var lastColumnsHidden = {};
 var lastWidth = {};
-var lastMain = 0;
 var resizeDelta = 100;
 var resizeTime = 0;
 var resizeTimeout = false;
@@ -546,12 +545,12 @@ function applySkin() {
 		themeReady();
 	}
 
-	tuneFilter();
-
 	makeFiltersResponsive();
 
 	setupResponsiveMenuAndTabs();
 
+	keepWindowSize();
+
 	// Add tooltips to graph drilldowns
 	$('.drillDown').tooltip({
 		content: function() {
@@ -599,79 +598,118 @@ function applySkin() {
 	});
 
 	$.when.apply(this, showPage).done(function() {
-		responsiveUI(null);
+		responsiveUI('force');
+	});
+}
+
+function markFilterTDs(child, filterNum) {
+	trNum = 0;
+
+	$('#'+child).find('tr').each(function() {
+		tdNum = 0;
+		$(this).find('td').each(function() {
+			$(this).attr('id', 'fn'+filterNum+'tr'+trNum+'td'+tdNum);
+			tdNum++;
+		});
+		trNum++;
 	});
 }
 
 function makeFiltersResponsive() {
 	storage=Storages.localStorage;
 
+	filterNum = 0;
+
 	if ($('div.cactiTableButton').closest('.cactiTable').find('.filterTable').length > 0) {
 		$('div.cactiTableButton').each(function() {
-			id    = $(this).closest('.cactiTable').attr('id');
-			child = id+'_child';
+			if ($(this).closest('.cactiTable').find('.filterTable').length) {
+				if ($(this).find('.cactiFilterState').length == 0) {
+					id    = $(this).closest('.cactiTable').attr('id');
+					child = id+'_child';
 
-			$(this).parent().css('cursor', 'pointer');
+					markFilterTDs(child, filterNum);
 
-			if ($(this).find('a').length) {
-				$(this).find('a').attr('title', $(this).find('a').text()).addClass('fa fa-plus').tooltip({
-					open: function (event, ui) {
-						id = $(this).closest('.cactiTable').attr('id');
-						$('#'+id).find('.cactiTableButton').tooltip('close');
-					},
-					close: function (event, ui) {
-						id = $(this).closest('.cactiTable').attr('id');
+					$(this).parent().css('cursor', 'pointer');
+
+					if ($(this).find('a').length) {
+						$(this).find('a').attr('title', $(this).find('a').text()).addClass('fa fa-plus').tooltip({
+							open: function (event, ui) {
+								id = $(this).closest('.cactiTable').attr('id');
+								$('#'+id).find('.cactiTableButton').tooltip('close');
+							},
+							close: function (event, ui) {
+								id = $(this).closest('.cactiTable').attr('id');
+							}
+						}).text('');
 					}
-				}).text('');
-			}
+				}
 
-			if ($('#'+child).find('.filterTable').length) {
-				$(this).append('<span style="display:none;" class="cactiFilter fa fa-filter"></span>');
+				if ($('#'+child).find('.filterTable').length) {
+					if ($(this).find('.cactiFilter').length == 0) {
+						$(this).append('<span style="display:none;" class="cactiFilter fa fa-filter"></span>');
 
-				$(this).attr('title', showHideFilter).tooltip({ track: true });
+						$(this).attr('title', showHideFilter).tooltip({ track: true });
 
-				$('.cactiFilter').click(function(event) {
-					//$('.filterTable').find('td').css('display', 'table-row');
-					//event.stopPropagation();
-				});
+						$('.cactiFilter').click(function(event) {
+							//$('.filterTable').find('td').css('display', 'table-row');
+							//event.stopPropagation();
+						});
 
-				id    = $(this).closest('.cactiTable').attr('id');
-				child = id+'_child';
+						id    = $(this).closest('.cactiTable').attr('id');
+						child = id+'_child';
 
-				if ($('#'+child).find('#clear').length) {
-					$(this).append('<span title="'+clearFilterTitle+'" style="display:none;" class="cactiFilterClear fa fa-trash-o"></span>');
+						if ($('#'+child).find('#clear').length) {
+							$(this).append('<span title="'+clearFilterTitle+'" style="display:none;" class="cactiFilterClear fa fa-trash-o"></span>');
 
-					$('.cactiFilterClear').click(function(event) {
-						event.stopPropagation();
-						$('#clear').trigger('click');
-					}).tooltip({
+							$('.cactiFilterClear').click(function(event) {
+								event.stopPropagation();
+								$('#clear').trigger('click');
+							}).tooltip({
+								open: function (event, ui) {
+									id = $(this).closest('.cactiTable').attr('id');
+									$('#'+id).find('.cactiTableButton').tooltip('close');
+								},
+								close: function (event, ui) {
+									id = $(this).closest('.cactiTable').attr('id');
+								}
+							});
+						}
+
+						toggleFilterAndIcon(id, child, true);
+
+						$(this).parent().click(function() {
+							id    = $(this).closest('.cactiTable').attr('id');
+							child = id+'_child';
+							toggleFilterAndIcon(id, child, false);
+						});
+
+						state = storage.get('filterVisibility');
+
+						if (state == 'hidden') {
+							$(this).append('<span class="cactiFilterState fa fa-angle-double-down"></span>');
+						} else {
+							$(this).append('<span class="cactiFilterState fa fa-angle-double-up"></span>');
+						}
+					}
+				}
+			} else {
+				if ($(this).find('a').length) {
+					$(this).find('a').attr('title', $(this).find('a').text()).addClass('fa fa-plus').tooltip({
 						open: function (event, ui) {
 							id = $(this).closest('.cactiTable').attr('id');
 							$('#'+id).find('.cactiTableButton').tooltip('close');
 						},
 						close: function (event, ui) {
 							id = $(this).closest('.cactiTable').attr('id');
-						}
-					});
 				}
-
-				toggleFilterAndIcon(id, child, true);
-
-				$(this).parent().click(function() {
-					id    = $(this).closest('.cactiTable').attr('id');
-					child = id+'_child';
-					toggleFilterAndIcon(id, child, false);
-				});
-			}
-
-			state = storage.get('filterVisibility');
-
-			if (state == 'hidden') {
-				$(this).append('<span class="cactiFilterState fa fa-angle-double-down"></span>');
-			} else {
-				$(this).append('<span class="cactiFilterState fa fa-angle-double-up"></span>');
+					}).text('');
+				}
 			}
 		});
+	} else if ($('div.cactiTableButton').length) {
+		if ($('div.cactiTableButton').find('a').length) {
+			$('div.cactiTableButton').find('a').attr('title', $('div.cactiTableButton').find('a').text()).addClass('fa fa-plus').tooltip().text('');
+		}
 	}
 }
 
@@ -727,33 +765,24 @@ function setupResponsiveMenuAndTabs() {
 		}
 	});
 
-	$(window).resize(function(event) {
-    	resizeTime = new Date();
-		myEvent = event;
-	    if (resizeTimeout === false) {
-			resizeTimeout = true;
-			setTimeout(function() {
-				responsiveUI(myEvent);
-			}, resizeDelta);
-		}
-	});
-
-	$(window).on('orientationchange', function() {
-		responsiveUI(null);
+	$(window).on('orientationchange, fullscreenchange', function() {
+		responsiveUI('force');
 	});
 }
 
 function responsiveUI(event) {
-    if (new Date() - resizeTime < resizeDelta) {
-		myEvent = event;
-        setTimeout(function() {
-			responsiveUI(myEvent);
-		}, resizeDelta);
+	if (event != 'force') {
+	    if (new Date() - resizeTime < resizeDelta) {
+			myEvent = event;
+			setTimeout(function() {
+				responsiveUI(myEvent);
+			}, resizeDelta);
 
-		return false;
-    } else {
-        resizeTimeout = false;
-    }
+			return false;
+		} else {
+			resizeTimeout = false;
+		}
+	}
 
 	if ($('.cactiTreeNavigationArea').length > 0) {
 		tree = true;
@@ -761,16 +790,6 @@ function responsiveUI(event) {
 		tree = false;
 	}
 
-	if (event == null) {
-		if (lastMain > 0) {
-			mainWidth = lastMain;
-		}else{
-			mainWidth = $('#main').width();
-		}
-	}else{
-		mainWidth = $('#main').width();
-	}
-
 	if ($(window).width() < 640) {
 		menuHide(tree);
 		menuHideResponsive = true;
@@ -787,41 +806,32 @@ function responsiveUI(event) {
 		menuShow(tree);
 	}
 
-	mainWidth = $('#main').width();
+	if ($('#navigation').length && $('#navigation').is(':visible')) {
+		mainWidth = $('body').innerWidth() - $('#navigation').width();
+	} else {
+		mainWidth = $('body').innerWidth();
+	}
 
 	/* change textbox and textarea widths */
-	if (event != null) {
-		$('input[type="text"], textarea').each(function() {
-			//console.log('Main:'+mainWidth+', Element:'+$(this).attr('id')+', Width:'+$(this).width());
-
-			if ($(this).attr('type') == 'text') {
-				offset = 20;
-			}else{
-				offset = 5;
-			}
-
-			if (mainWidth != 100) {
-				if ($(this).width() > mainWidth) {
-					$(this).css('max-width', (mainWidth - offset)+'px');
-				}else{
-					$(this).css('max-width', '');
-				}
-
-				if ($(this).width() > mainWidth) {
-					$(this).css('max-width', (mainWidth - offset)+'px');
-				}
-			}
-		});
-	}
-
-	if (event != null && !$(event.target).hasClass('ui-resizable')) {
-		height = Math.max(document.body.scrollHeight, $(window).height());
-		if (tree) {
-			$('.cactiTreeNavigationArea').css('height', height);
+	$('input[type="text"], textarea').each(function() {
+		if ($(this).attr('type') == 'text') {
+			offset = 20;
 		}else{
-			$('.cactiConsoleNavigationArea').css('height', height);
+			offset = 5;
 		}
-	}
+
+		if (mainWidth != 100) {
+			if ($(this).width() > mainWidth) {
+				$(this).css('max-width', (mainWidth - offset)+'px');
+			}else{
+				$(this).css('max-width', '');
+			}
+
+			if ($(this).width() > mainWidth) {
+				$(this).css('max-width', (mainWidth - offset)+'px');
+			}
+		}
+	});
 
 	$('.filterTable').each(function() {
 		tuneFilter($(this), mainWidth);
@@ -836,6 +846,75 @@ function responsiveUI(event) {
 	});
 }
 
+function responsiveResizeGraphs() {
+	if ($('.graphimage').length == 0) {
+		return false;
+	}
+
+	if ($('#navigation').length && $('#navigation').is(':visible')) {
+		mainWidth = $('body').innerWidth() - $('#navigation').width();
+	} else {
+		mainWidth = $('body').innerWidth();
+	}
+
+	myColumns = $('#columns').val();
+	isThumb   = $('#thumbnails').is(':checked');
+	graphRow  = $('.tableRowGraph:first').width();
+	drillDown = $('.graphDrillDown:first').outerWidth() + 15;
+
+	if (myColumns == null) {
+		myColumns = 1;
+	}
+
+	if (mainWidth < graphRow) {
+		graphRow = mainWidth - drillDown;
+	} else if (graphRow == 0) {
+		graphRow = mainWidth;
+	}
+
+	myWidth = parseInt((graphRow - (drillDown * myColumns)) / myColumns);
+
+	$('.graphimage').each(function() {
+		graph_id = $(this).attr('id').replace('wrapper_','');
+
+		/* original image attributes */
+		image_width   = $(this).attr('image_width');
+		image_height  = $(this).attr('image_height');
+		canvas_top    = $(this).attr('canvas_top');
+		canvas_left   = $(this).attr('canvas_left');
+		canvas_width  = $(this).attr('canvas_width');
+		canvas_height = $(this).attr('canvas_height');
+
+		if (isThumb || myWidth < image_width) {
+			ratio = myWidth / image_width;
+		} else {
+			ratio = 1;
+		}
+
+		new_image_width       = parseInt(image_width * ratio)
+		new_image_height      = parseInt(image_height * ratio)
+		new_canvas_width      = parseInt(canvas_width  * ratio);
+		new_canvas_height     = parseInt(canvas_height * ratio);
+		new_canvas_graph_top  = parseInt(canvas_top  * ratio);
+		new_canvas_graph_left = parseInt(canvas_left * ratio);
+
+		$(this).attr('graph_width', new_canvas_width);
+		$(this).attr('graph_height', new_canvas_height);
+		$(this).attr('graph_top', new_canvas_graph_top);
+		$(this).attr('graph_left', new_canvas_graph_left);
+
+		$(this).css('width', new_image_width);
+		$(this).css('height', new_image_height);
+
+		$('#zoom-container').remove();
+		$(this).zoom({
+			inputfieldStartTime : 'date1',
+			inputfieldEndTime : 'date2',
+			serverTimeOffset : timeOffset
+		});
+	});
+}
+
 function countHiddenCols(object) {
 	hidden = 0;
 	$(object).find('th').each(function() {
@@ -849,8 +928,8 @@ function countHiddenCols(object) {
 
 function tuneTable(object, width) {
 	rows           = $(object).find('tr').length;
-	width          = parseInt(width);
-	tableWidth     = parseInt($(object).width());
+	width          = width;
+	tableWidth     = $(object).width();
 	totalCols      = $(object).find('th').length;
 	reducedWidth   = 0;
 	columnsHidden  = countHiddenCols(object);
@@ -859,7 +938,6 @@ function tuneTable(object, width) {
 
 	if (rows > 101) return false;
 
-	//console.log('totCols: '+totalCols+', hidCols: '+columnsHidden+', visCols: '+visibleColumns+', tabWid: '+tableWidth+', wid: '+width+', redWid: '+reducedWidth);
 	if (tableWidth > width) {
 		column = totalCols;
 		hasCheckbox = $(object).find('th.tableSubHeaderCheckbox').length;
@@ -872,7 +950,7 @@ function tuneTable(object, width) {
 
 		$($(object).find('th').not('.noHide').get().reverse()).each(function() {
 			if (!$(this).hasClass('tableSubHeaderCheckbox') && $(this).is(':visible')) {
-				reducedWidth += parseInt($(this).width());
+				reducedWidth += $(this).width();
 				$('#'+id+' th:nth-child('+column+')').hide();
 				$('#'+id+' td:nth-child('+column+')').hide();
 				columnsHidden++;
@@ -914,19 +992,32 @@ function tuneTable(object, width) {
 }
 
 function tuneFilter(object, width) {
-	filter = 'input[id="refresh"], input[id="clear"], input[id="save"], input[id="tsrefresh"], input[id="tsclear"]';
-	buttons = $(object).find(filter).length;
+	filter  = 'input[id="refresh"], input[id="clear"], input[id="save"], input[id="tsrefresh"], input[id="tsclear"]';
+	buttons = 0;
+	visTds  = $(object).find('td:visible').length;
+
+	// Find the td's with buttons
+	$($(object).find('td').get().reverse()).each(function() {
+		if ($(this).find(filter).length > 0) {
+			buttons++;
+		}
+	});
+	minTds  = 2 + buttons;
 
 	if ($(object).width() > width) {
 		$($(object).find('td').get().reverse()).each(function() {
-			if (!$(this).find(filter).length) {
-				// always show two objects
-				if ($(object).find('td:visible').length - buttons > 2) {
-					$(this).hide();
+			if (visTds < minTds) {
+				return false;
+			}
 
-					if ($(this).closest('td').prev().find('input, select').length == 0) {
-						$(this).closest('td').prev().hide();
-					}
+			if ($(this).find(filter).length == 0) {
+				// always show two objects
+				$(this).hide();
+				visTds--;
+
+				if ($(this).closest('td').prev().find('input, select').length == 0) {
+					$(this).closest('td').prev().hide();
+					visTds--;
 				}
 			}
 
@@ -955,34 +1046,48 @@ function tuneFilter(object, width) {
 	}
 }
 
-function menuHide(tree) {
-	if (marginLeft == null) {
-		marginLeft = parseInt($('#navigation_right').css('margin-left'));
+function menuHide() {
+	myClass = '';
+    curMargin = $('#navigation').outerWidth();
+	if (curMargin > 0) {
+		marginLeft = curMargin;
 	}
 
-	if (tree) {
+	if ($('.cactiTreeNavigationArea').length) {
 		myClass = '.cactiTreeNavigationArea';
-	}else{
+	} else if ($('.cactiConsoleNavigationArea').length) {
 		myClass = '.cactiConsoleNavigationArea';
 	}
 
 	$('#navigation_right').animate({'margin-left': '0px'}, 20);
-	$(myClass).hide('slide', {direction: 'left'}, 20);
+
+	if (myClass != '') {
+		$(myClass).hide('slide', {direction: 'left'}, 20, function() {
+			responsiveResizeGraphs();
+		});
+	}
 
 	menuOpen = false;
 }
 
 function menuShow(tree) {
-	if (tree) {
+	myClass = '';
+
+	if ($('.cactiTreeNavigationArea').length) {
 		myClass = '.cactiTreeNavigationArea';
-	}else{
+	} else if ($('.cactiConsoleNavigationArea').length) {
 		myClass = '.cactiConsoleNavigationArea';
 	}
 
-	if (marginLeft != null) {
+	if (marginLeft > 0) {
 		$('#navigation_right').animate({'margin-left': marginLeft}, 20);
 	}
-	$(myClass).show('slide', {direction: 'left'}, 20);
+
+	if (myClass != '') {
+		$(myClass).show('slide', {direction: 'left'}, 20, function() {
+			responsiveResizeGraphs();
+		});
+	}
 
 	menuOpen = true;
 }
@@ -1191,13 +1296,6 @@ function setupUserMenu() {
 }
 
 function setupSpecialKeys() {
-	$('#filter, #rfilter').unbind('keypress').attr('title', clearSearchFilter);
-	$('#filter, #rfilter').tooltip({ closed: true }).on('focus', function() { $('#filter').tooltip('close'); }).on('click', function() { $(this).tooltip('close'); });
-
-	$('#filter, #rfilter').bind('keypress', 'ctrl+shift+x', function() {
-		$('#filter, #rfilter').val('').css('text-align', 'left').submit();
-	});
-
 	if (!isMobile.any()) {
 		$('#filter, #rfilter').focus();
 	}else{
@@ -1282,7 +1380,7 @@ function saveTableWidths(initial) {
 		if (key !== undefined) {
 			if (initial && items.length) {
 				$('#'+key).find('th.ui-resizable').each(function(data) {
-					if (parseInt(items[i]) == 0) {
+					if (items[i] == 0) {
 						items[i] = $(this).width();
 						sizes[i] = items[i];
 					}
@@ -1431,10 +1529,74 @@ $(function() {
 			}
 		});
 	}
-
-	responsiveUI(null);
 });
 
+/* only perform the recalculation of elements at the final end of the windows resize event */
+var waitForFinalEvent = (function () {
+  var timers = {};
+  return function (callback, ms, uniqueId) {
+    if (!uniqueId) {
+      uniqueId = "Don't call this twice without a uniqueId";
+    }
+    if (timers[uniqueId]) {
+      clearTimeout (timers[uniqueId]);
+    }
+    timers[uniqueId] = setTimeout(callback, ms);
+  };
+})();
+
+function keepWindowSize() {
+	$(window).resize(function (event) {
+		$('.cactiGraphContentArea').show();
+
+   		resizeTime = new Date();
+		myEvent = event;
+		if (resizeTimeout === false) {
+			resizeTimeout = true;
+			setTimeout(function() {
+				responsiveUI(myEvent);
+			}, resizeDelta);
+		}
+		heightPage = $(window).height();
+
+		if ($('#cactiPageHead').is(':visible')) {
+			heightPageHead = $('#cactiPageHead').outerHeight();
+		} else {
+			heightPageHead = 0;
+		}
+
+		if ($('#breadCrumbBar').is(':visible')) {
+			heightBreadCrumbBar = $('#breadCrumbBar').outerHeight();
+		} else {
+			heightBreadCrumbBar = 0;
+		}
+
+		if ($('#cactiPageBottom').is(':visible')) {
+			heightPageBottom = $('#cactiPageBottom').outerHeight();
+		} else {
+			heightPageBottom = 0;
+		}
+
+		heightPageContent = heightPage - heightPageHead - heightPageBottom - heightBreadCrumbBar;
+
+		if (theme != 'classic') {
+			$('body').css('height', heightPage);
+			$('#cactiContent, #navigation, #navigation_right, #main').css('height', heightPageContent);
+
+			// Handle links pages
+			$('#content').css({'width':'100%', 'height':heightPageContent-4});
+		} else {
+			// Handle links pages
+			$('#content').css({'width':'100%', 'height':$(document).height()});
+		}
+
+		navWidth = $('#navigation').width();
+		$('#searcher').css('width', navWidth-70);
+
+		responsiveResizeGraphs();
+	}).resize();
+}
+
 /* Graph related javascript functions */
 if (typeof urlPath == 'undefined') {
 	var urlPath = '';
@@ -1718,15 +1880,22 @@ function dryRunRangeFill(local_graph_id) {
 
 function redrawGraph(graph_id) {
 	mainWidth = $('#main').width();
-	myColumns = $('#columns').val();
 	isThumb   = $('#thumbnails').is(':checked');
 
-	if (isThumb) {
-		myWidth = (mainWidth-(30*myColumns))/myColumns;
+	myColumns = $('#columns').val();
+	graphRow  = $('.tableRowGraph').width();
+	drillDown = $('.graphDrillDown:first').outerWidth() + 10;
+
+	if (mainWidth < graphRow) {
+		graphRow = mainWidth - drillDown;
+	} else if (graphRow == 0) {
+		graphRow = mainWidth;
 	}
 
-	graph_height=$('#wrapper_'+graph_id).attr('graph_height');
-	graph_width=$('#wrapper_'+graph_id).attr('graph_width');
+	myWidth = (graphRow-(drillDown * myColumns)) / myColumns;
+
+	graph_height= $('#wrapper_'+graph_id).attr('graph_height');
+	graph_width = $('#wrapper_'+graph_id).attr('graph_width');
 
 	$.getJSON(urlPath+'graph_json.php?rra_id=0'+
 		'&local_graph_id='+graph_id+
@@ -1736,17 +1905,36 @@ function redrawGraph(graph_id) {
 		'&graph_width='+graph_width+
 		(isThumb ? '&graph_nolegend=true':''),
 		function(data) {
-			if (isThumb && myWidth < data.image_width) {
+			if (myWidth < data.image_width) {
 				ratio=myWidth/data.image_width;
-				data.image_width  *= ratio;
-				data.image_height *= ratio;
-				data.graph_width  *= ratio;
-				data.graph_height *= ratio;
-				data.graph_top    *= ratio;
-				data.graph_left   *= ratio;
+				data.image_width  = parseInt(data.image_width  * ratio);
+				data.image_height = parseInt(data.image_height * ratio);
+				data.graph_width  = parseInt(data.graph_width  * ratio);
+				data.graph_height = parseInt(data.graph_height * ratio);
+				data.graph_top    = parseInt(data.graph_top  * ratio);
+				data.graph_left   = parseInt(data.graph_left * ratio);
 			}
 
-			$('#wrapper_'+data.local_graph_id).html("<img class='graphimage' id='graph_"+data.local_graph_id+"' src='data:image/"+data.type+";base64,"+data.image+"' graph_start='"+data.graph_start+"' graph_end='"+data.graph_end+"' graph_left='"+data.graph_left+"' graph_top='"+data.graph_top+"' graph_width='"+data.graph_width+"' graph_height='"+data.graph_height+"' width='"+data.image_width+"' height='"+data.image_height+"' image_width='"+data.image_width+"' image_height='"+data.image_height+"' value_min='"+data.value_min+"' value_max='"+data.value_max+"'>");
+			$('#wrapper_'+data.local_graph_id).html(
+				"<img class='graphimage' id='graph_"+data.local_graph_id+"'"+
+				" src='data:image/"+data.type+";base64,"+data.image+"'"+
+				" graph_start='"+data.graph_start+"'"+
+				" graph_end='"+data.graph_end+"'"+
+				" graph_left='"+data.graph_left+"'"+
+				" graph_top='"+data.graph_top+"'"+
+				" graph_width='"+data.graph_width+"'"+
+				" graph_height='"+data.graph_height+"'"+
+				" width='"+data.image_width+"'"+
+				" height='"+data.image_height+"'"+
+				" image_width='"+data.image_width+"'"+
+				" image_height='"+data.image_height+"'"+
+				" canvas_top='"+data.graph_top+"'"+
+				" canvas_left='"+data.graph_left+"'"+
+				" canvas_width='"+data.graph_width+"'"+
+				" canvas_height='"+data.graph_height+"'"+
+				" value_min='"+data.value_min+"'"+
+				" value_max='"+data.value_max+"'>"
+			);
 		}
 	);
 }
@@ -1806,20 +1994,41 @@ function initializeGraphs() {
 			function(data) {
 				if (myWidth < data.image_width) {
 					ratio=myWidth/data.image_width;
-					data.image_width  *= ratio;
-					data.image_height *= ratio;
-					data.graph_width  *= ratio;
-					data.graph_height *= ratio;
-					data.graph_top    *= ratio;
-					data.graph_left   *= ratio;
+					data.image_width  = parseInt(data.image_width  * ratio);
+					data.image_height = parseInt(data.image_height * ratio);
+					data.graph_width  = parseInt(data.graph_width  * ratio);
+					data.graph_height = parseInt(data.graph_height * ratio);
+					data.graph_top    = parseInt(data.graph_top  * ratio);
+					data.graph_left   = parseInt(data.graph_left * ratio);
 				}
 
-				$('#wrapper_'+data.local_graph_id).html("<img class='graphimage' id='graph_"+data.local_graph_id+"' src='data:image/"+data.type+";base64,"+data.image+"' graph_start='"+data.graph_start+"' graph_end='"+data.graph_end+"' graph_left='"+data.graph_left+"' graph_top='"+data.graph_top+"' graph_width='"+data.graph_width+"' graph_height='"+data.graph_height+"' width='"+data.image_width+"' height='"+data.image_height+"' image_width='"+data.image_width+"' image_height='"+data.image_height+"' value_min='"+data.value_min+"' value_max='"+data.value_max+"'>");
+				$('#wrapper_'+data.local_graph_id).html(
+					"<img class='graphimage' id='graph_"+data.local_graph_id+"'"+
+					" src='data:image/"+data.type+";base64,"+data.image+"'"+
+					" graph_start='"+data.graph_start+"'"+
+					" graph_end='"+data.graph_end+"'"+
+					" graph_left='"+data.graph_left+"'"+
+					" graph_top='"+data.graph_top+"'"+
+					" graph_width='"+data.graph_width+"'"+
+					" graph_height='"+data.graph_height+"'"+
+					" width='"+data.image_width+"'"+
+					" height='"+data.image_height+"'"+
+					" image_width='"+data.image_width+"'"+
+					" image_height='"+data.image_height+"'"+
+					" canvas_top='"+data.graph_top+"'"+
+					" canvas_left='"+data.graph_left+"'"+
+					" canvas_width='"+data.graph_width+"'"+
+					" canvas_height='"+data.graph_height+"'"+
+					" value_min='"+data.value_min+"'"+
+					" value_max='"+data.value_max+"'>"
+				);
+
 				$("#graph_"+data.local_graph_id).zoom({
 					inputfieldStartTime : 'date1',
 					inputfieldEndTime : 'date2',
 					serverTimeOffset : timeOffset
 				});
+
 				realtimeArray[data.local_graph_id] = false;
 		});
 	});
@@ -1855,7 +2064,11 @@ function initializeGraphs() {
 		if (realtimeArray[graph_id]) {
 			$('#wrapper_'+graph_id).html(keepRealtime[graph_id]).change();
 			$(this).html("<img class='drillDown' title='"+realtimeClickOn+"' alt='' src='"+urlPath+"images/chart_curve_go.png'>");
-			$(this).find('img').tooltip().zoom({ inputfieldStartTime : 'date1', inputfieldEndTime : 'date2', serverTimeOffset : timeOffset });
+			$(this).find('img').tooltip().zoom({ 
+				inputfieldStartTime : 'date1', 
+				inputfieldEndTime : 'date2', 
+				serverTimeOffset : timeOffset 
+			});
 			realtimeArray[graph_id] = false;
 			setFilters();
 		}else{
